==> plasma-sd-service-compose-0.4.1-sources.jar: com/sdds/plasma/sd/service/styles/progress/ProgressStyles.kt <==
package com.sdds.plasma.sd.service.styles.progress

import androidx.compose.runtime.Composable
import com.sdds.compose.uikit.ProgressBar
import com.sdds.compose.uikit.ProgressBarStyle
import com.sdds.compose.uikit.ProgressBarStyleBuilder
import com.sdds.plasma.sd.service.theme.PlasmaSdServiceTheme

/**
 * Стиль [ProgressBar] цвета Default
 */
val ProgressBar.Default: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultSolidDefault)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Secondary
 */
val ProgressBar.Secondary: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultSolidTertiary)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Accent
 */
val ProgressBar.Accent: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultAccent)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета GradientAccent
 */
val ProgressBar.GradientAccent: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.gradients.surfaceDefaultAccentGradient)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Positive
 */
val ProgressBar.Positive: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultPositive)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Warning
 */
val ProgressBar.Warning: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultWarning)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Negative
 */
val ProgressBar.Negative: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultNegative)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

==> plasma-sd-service-compose-0.8.0-sources.jar: com/sdds/plasma/sd/service/styles/progress/ProgressStyles.kt <==
package com.sdds.plasma.sd.service.styles.progress

import androidx.compose.runtime.Composable
import com.sdds.compose.uikit.ProgressBar
import com.sdds.compose.uikit.ProgressBarStyle
import com.sdds.compose.uikit.ProgressBarStyleBuilder
import com.sdds.plasma.sd.service.theme.PlasmaSdServiceTheme

/**
 * Стиль [ProgressBar] цвета Default
 */
val ProgressBar.Default: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultSolidDefault)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Secondary
 */
val ProgressBar.Secondary: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultSolidTertiary)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Accent
 */
val ProgressBar.Accent: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultAccent)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета GradientAccent
 */
val ProgressBar.GradientAccent: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.gradients.surfaceDefaultAccentGradient)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Positive
 */
val ProgressBar.Positive: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultPositive)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Warning
 */
val ProgressBar.Warning: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultWarning)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Negative
 */
val ProgressBar.Negative: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultNegative)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }

/**
 * Стиль [ProgressBar] цвета Negative
 */
val ProgressBar.Info: ProgressBarStyleBuilder
    @Composable
    get() = ProgressBarStyle.builder()
        .colors {
            indicatorColor(PlasmaSdServiceTheme.colors.surfaceDefaultInfo)
            backgroundColor(PlasmaSdServiceTheme.colors.surfaceDefaultTransparentSecondary)
        }
